PhpTokenType

Enum PhpTokenType 

pub enum PhpTokenType {
Show 176 variants Whitespace, Newline, Comment, StringLiteral, NumberLiteral, BooleanLiteral, NullLiteral, Identifier, Variable, Abstract, And, Array, As, Break, Callable, Case, Catch, Class, Clone, Const, Continue, Declare, Default, Do, Echo, Else, Elseif, Empty, Enddeclare, Endfor, Endforeach, Endif, Endswitch, Endwhile, Eval, Exit, Extends, Final, Finally, For, Foreach, Function, Global, Goto, If, Implements, Include, IncludeOnce, Instanceof, Insteadof, Interface, Isset, List, Namespace, New, Or, Print, Private, Protected, Public, Require, RequireOnce, Return, Static, Switch, Throw, Trait, Try, Unset, Use, Var, While, Xor, Yield, YieldFrom, Plus, Minus, Multiply, Divide, Modulo, Power, Concat, Equal, Identical, NotEqual, NotIdentical, Less, Greater, LessEqual, GreaterEqual, Spaceship, LogicalAnd, LogicalOr, LogicalXor, LogicalNot, BitwiseAnd, BitwiseOr, BitwiseXor, BitwiseNot, LeftShift, RightShift, Assign, PlusAssign, MinusAssign, MultiplyAssign, DivideAssign, ModuloAssign, PowerAssign, ConcatAssign, BitwiseAndAssign, BitwiseOrAssign, BitwiseXorAssign, LeftShiftAssign, RightShiftAssign, Increment, Decrement, Arrow, DoubleArrow, NullCoalesce, NullCoalesceAssign, Ellipsis, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Semicolon, Comma, Dot, Question, Colon, DoubleColon, Backslash, At, Dollar, OpenTag, CloseTag, EchoTag, Eof, Error, Root, ClassDef, FunctionDef, MethodDef, PropertyDef, ConstDef, TraitDef, InterfaceDef, NamespaceDef, UseStatement, IfStatement, WhileStatement, DoWhileStatement, ForStatement, ForeachStatement, SwitchStatement, TryStatement, CatchBlock, FinallyBlock, ExpressionStatement, ReturnStatement, ThrowStatement, BreakStatement, ContinueStatement, EchoStatement, GlobalStatement, StaticStatement, UnsetStatement, CompoundStatement, Literal, ParenthesizedExpression, CallExpression, ArrayAccessExpression, MemberAccessExpression, BinaryExpression,
}
Enum representing all possible token types in PHP

Variants



Whitespace

Whitespace characters



Newline

Newline characters



Comment

Comment



StringLiteral

String literal



NumberLiteral

Number literal



BooleanLiteral

Boolean literal (true, false)



NullLiteral

Null literal



Identifier

Identifier



Variable

Variable identifier (starting with $)



Abstract

‘abstract’ keyword



And

‘and’ operator



Array

‘array’ keyword/type



As

‘as’ keyword



Break

‘break’ keyword



Callable

‘callable’ type



Case

‘case’ keyword



Catch

‘catch’ keyword



Class

‘class’ keyword



Clone

‘clone’ keyword



Const

‘const’ keyword



Continue

‘continue’ keyword



Declare

‘declare’ keyword



Default

‘default’ keyword



Do

‘do’ keyword



Echo

‘echo’ keyword



Else

‘else’ keyword



Elseif

‘elseif’ keyword



Empty

‘empty’ keyword



Enddeclare

‘enddeclare’ keyword



Endfor

‘endfor’ keyword



Endforeach

‘endforeach’ keyword



Endif

‘endif’ keyword



Endswitch

‘endswitch’ keyword



Endwhile

‘endwhile’ keyword



Eval

‘eval’ keyword



Exit

‘exit’ keyword



Extends

‘extends’ keyword



Final

‘final’ keyword



Finally

‘finally’ keyword



For

‘for’ keyword



Foreach

‘foreach’ keyword



Function

‘function’ keyword



Global

‘global’ keyword



Goto

‘goto’ keyword



If

‘if’ keyword



Implements

‘implements’ keyword



Include

‘include’ keyword



IncludeOnce

‘include_once’ keyword



Instanceof

‘instanceof’ operator



Insteadof

‘insteadof’ keyword



Interface

‘interface’ keyword



Isset

‘isset’ keyword



List

‘list’ keyword



Namespace

‘namespace’ keyword



New

‘new’ keyword



Or

‘or’ operator



Print

‘print’ keyword



Private

‘private’ keyword



Protected

‘protected’ keyword



Public

‘public’ keyword



Require

‘require’ keyword



RequireOnce

‘require_once’ keyword



Return

‘return’ keyword



Static

‘static’ keyword



Switch

‘switch’ keyword



Throw

‘throw’ keyword



Trait

‘trait’ keyword



Try

‘try’ keyword



Unset

‘unset’ keyword



Use

‘use’ keyword



Var

‘var’ keyword



While

‘while’ keyword



Xor

‘xor’ operator



Yield

‘yield’ keyword



YieldFrom

‘yield from’ keyword



Plus

Plus operator (+)



Minus

Minus operator (-)



Multiply

Multiply operator (*)



Divide

Divide operator (/)



Modulo

Modulo operator (%)



Power

Power operator (**)



Concat

Concatenation operator (.)



Equal

Equality operator (==)



Identical

Identity operator (===)



NotEqual

Inequality operator (!= or <>)



NotIdentical

Non-identity operator (!==)



Less

Less than operator (<)



Greater

Greater than operator (>)



LessEqual

Less than or equal operator (<=)



GreaterEqual

Greater than or equal operator (>=)



Spaceship

Spaceship operator (<=>)



LogicalAnd

Logical AND operator (&&)



LogicalOr

Logical OR operator (||)



LogicalXor

Logical XOR operator



LogicalNot

Logical NOT operator (!)



BitwiseAnd

Bitwise AND operator (&)



BitwiseOr

Bitwise OR operator (|)



BitwiseXor

Bitwise XOR operator (^)



BitwiseNot

Bitwise NOT operator (~)



LeftShift

Left shift operator (<<)



RightShift

Right shift operator (>>)



Assign

Assignment operator (=)



PlusAssign

Plus assignment operator (+=)



MinusAssign

Minus assignment operator (-=)



MultiplyAssign

Multiply assignment operator (*=)



DivideAssign

Divide assignment operator (/=)



ModuloAssign

Modulo assignment operator (%=)



PowerAssign

Power assignment operator (**=)



ConcatAssign

Concatenation assignment operator (.=)



BitwiseAndAssign

Bitwise AND assignment operator (&=)



BitwiseOrAssign

Bitwise OR assignment operator (|=)



BitwiseXorAssign

Bitwise XOR assignment operator (^=)



LeftShiftAssign

Left shift assignment operator (<<=)



RightShiftAssign

Right shift assignment operator (>>=)



Increment

Increment operator (++)



Decrement

Decrement operator (–)



Arrow

Object member access operator (->)



DoubleArrow

Array element arrow (=>)



NullCoalesce

Null coalescing operator (??)



NullCoalesceAssign

Null coalescing assignment operator (??=)



Ellipsis

Ellipsis operator (…)



LeftParen

Left parenthesis (()



RightParen

Right parenthesis ())



LeftBracket

Left bracket ([)



RightBracket

Right bracket (])



LeftBrace

Left brace ({)



RightBrace

Right brace (})



Semicolon

Semicolon (;)



Comma

Comma (,)



Dot

Dot operator (.)



Question

Question mark (?)



Colon

Colon operator (:)



DoubleColon

Scope resolution operator (::)



Backslash

Backslash ()



At

Error suppression operator (@)



Dollar

Dollar sign ($)



OpenTag

PHP opening tag (<?php)



CloseTag

PHP closing tag (?>)



EchoTag

PHP echo tag (<?=)



Eof

End of file



Error

Error token



Root

Root node of the document



ClassDef

Class definition



FunctionDef

Function definition



MethodDef

Method definition



PropertyDef

Property definition



ConstDef

Constant definition



TraitDef

Trait definition



InterfaceDef

Interface definition



NamespaceDef

Namespace definition



UseStatement

Use statement



IfStatement

If statement



WhileStatement

While statement



DoWhileStatement

Do-while statement



ForStatement

For statement



ForeachStatement

Foreach statement



SwitchStatement

Switch statement



TryStatement

Try statement



CatchBlock

Catch block



FinallyBlock

Finally block



ExpressionStatement

Expression statement



ReturnStatement

Return statement



ThrowStatement

Throw statement



BreakStatement

Break statement



ContinueStatement

Continue statement



EchoStatement

Echo statement



GlobalStatement

Global statement



StaticStatement

Static statement



UnsetStatement

Unset statement



CompoundStatement

Compound statement (block)



Literal

Literal expression



ParenthesizedExpression

Parenthesized expression



CallExpression

Function or method call



ArrayAccessExpression

Array access expression



MemberAccessExpression

Member access expression



BinaryExpression

Binary expression

Implementations

Source

impl PhpTokenType

pub fn is_token(&self) -> bool

Checks if this syntax kind represents a token (leaf node).

Source

impl PhpTokenType

pub fn is_element(&self) -> bool

Checks if this syntax kind represents a composite element (non-leaf node).